==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/antistring/translations/antistring_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>Antistring</source>
        <translation>Antyłańcuszek</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Enable Antistring</source>
        <translation>Włącz antyłańcuszek</translation>
    </message>
    <message>
        <source>Block message</source>
        <translation>Blokuj wiadomość</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation>Pouczenie</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Logowanie</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Loguj wiadomości do pliku</translation>
    </message>
    <message>
        <source>Conditions</source>
        <translation>Warunki</translation>
    </message>
    <message>
        <source>Antistring notifications</source>
        <translation>Powiadomienia antyłańcuszka</translation>
    </message>
</context>
<context>
    <name>Antistring</name>
    <message>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation>     DATA I CZAS      ::   ID   ::    WIADOMOŚĆ
</translation>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <source>Condition</source>
        <translation>Warunek</translation>
    </message>
    <message>
        <source>Don&apos;t use</source>
        <translation>Nie używaj</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Współczynnik</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Zmień</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>AntistringNotification</name>
    <message>
        <source>Antistring</source>
        <translation>Antyłańcuszek</translation>
    </message>
    <message>
        <source>Your interlocutor send you love letter</source>
        <translation>Twój rozmówca wysłał Ci łańcuszek szczęścia</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/antistring/translations/antistring_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>Antistring</source>
        <translation>Antyłańcuszek</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Enable Antistring</source>
        <translation>Włącz antyłańcuszek</translation>
    </message>
    <message>
        <source>Block message</source>
        <translation>Blokuj wiadomość</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation>Pouczenie</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Logowanie</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Loguj wiadomości do pliku</translation>
    </message>
    <message>
        <source>Conditions</source>
        <translation>Warunki</translation>
    </message>
    <message>
        <source>Antistring notifications</source>
        <translation>Powiadomienia antyłańcuszka</translation>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <source>Condition</source>
        <translation>Warunek</translation>
    </message>
    <message>
        <source>Don&apos;t use</source>
        <translation>Nie używaj</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Współczynnik</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Zmień</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>AntistringMessageFilter</name>
    <message>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation>     DATA I CZAS      ::   ID   ::    WIADOMOŚĆ
</translation>
    </message>
</context>
<context>
    <name>AntistringNotificationService</name>
    <message>
        <source>Antistring</source>
        <translation>Antyłańcuszek</translation>
    </message>
    <message>
        <source>Your interlocutor send you love letter</source>
        <translation>Twój rozmówca wysłał Ci łańcuszek szczęścia</translation>
    </message>
</context>
</TS>
